<?php
/*
* 求人情報プラグイン
* カテゴリ管理コントローラー
*
* PHP 5.4.x
*
* @copyright    Copyright (c) hiniarata co.ltd
* @link         https://hiniarata.jp
* @package      Recruit Plugin Project
* @since        ver.0.9.0
*/

/**
* 求人情報 カテゴリ管理コントローラー
*
* @package baser.plugins.recruit
*/
class RecruitCategoryConfigsController extends RecruitAppController {

  /**
  * クラス名
  *
  * @var string
  * @access public
  */
  public $name = 'RecruitCategoryConfigs';

  /**
  * コンポーネント
  *
  * @var array
  * @access public
  */
  public $components = array('BcAuth', 'Cookie', 'BcAuthConfigure', 'Security');

  /**
  * モデル
  *
  * @var array
  * @access public
  */
  public $uses = array('Recruit.RecruitCategory');

  /**
  * ぱんくずナビ
  *
  * @var string
  * @access public
  */
  public $crumbs = array(
    array('name' => 'プラグイン管理', 'url' => array('plugin' => '', 'controller' => 'plugins', 'action' => 'index')),
    array('name' => '求人情報カテゴリ管理', 'url' => array('controller' => 'recruit_category_configs', 'action' => 'index'))
  );

  /**
  * サブ求人情報エレメント
  *
  * @var array
  * @access public
  */
  public $subMenuElements = array('recruit');

  /**
  * beforeFilter
  *
  * @return	void
  * @access 	public
  */
  public function beforeFilter() {
    parent::beforeFilter();
    //CSRF対策（トークンの有効期限延長）
    $this->Security->csrfCheck = true;
    $this->Security->csrfExpires = '+1 hour';
  }

  /**
  * [ADMIN] 一覧表示
  *
  * @return void
  */
  public function admin_index() {
	// 画面表示情報設定
	$default = array(
		'named' => array(
			'num' => $this->siteConfigs['admin_list_num']
		),
	);
	$this->setViewConditions('RecruitCategory', array('default' => $default));

    //データの取得
    $conditions = array();
    $this->paginate = array('conditions' => $conditions,
      'order' => 'RecruitCategory.id DESC',
      'limit' => $this->passedArgs['num'],
    );
    /* 表示設定 */
    $this->set('categories', $this->paginate('RecruitCategory'));
    $this->pageTitle = '求人情報 カテゴリ一覧';
  }

  /**
  * [ADMIN] 新規登録
  *
  * @return void
  */
  public function admin_add() {
    //登録ボタン押下後
    if (!empty($this->request->data)) {
      if ($this->RecruitCategory->save($this->request->data)) {
        $this->setMessage('求人情報にカテゴリ「'. h($this->request->data['RecruitCategory']['name']).'」を登録しました。', false, true);
        $this->redirect(array('action' => 'index'));
      } else {
        $this->setMessage('入力エラーです。内容を修正してください。', true);
      }
    }
    //テンプレートはdefaultを初期表示にしたい。
    $this->set('template', 'default');
    /* 表示設定 */
    $this->pageTitle = '求人情報 新規登録';
    $this->render('form');
  }

  /**
  * [ADMIN] 編集
  *
  * @param int $id 求人情報ID
  * @return void
  */
  public function admin_edit($id = null) {
    /* 除外処理 */
    if (empty($id)) {
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }

    //登録ボタン押下後
    if (!empty($this->request->data)) {
      if ($this->RecruitCategory->save($this->request->data)) {
        $this->setMessage('求人情報にカテゴリ「'. h($this->request->data['RecruitCategory']['name']).'」を編集しました。', false, true);
        $this->redirect(array('action' => 'index'));
      } else {
        $this->setMessage('入力エラーです。内容を修正してください。', true);
      }

    //編集画面初期表示
    } else {
      /* データ取得 */
      $category = $this->RecruitCategory->findById($id);
      /* 除外処理 */
      if (empty($category)) {
        $this->setMessage('無効なIDです。', true);
        $this->redirect(array('action' => 'index'));
      }
      $this->request->data = $category;
    }

    //カテゴリの設定を取得
    $category = $this->RecruitCategory->findById($id);
    //テンプレート初期状態をdefaultにしたい。
    if (empty($category['RecruitCategory']['template'])) {
      $template = 'default';
    } else {
      $template = $category['RecruitCategory']['template'];
    }
    $this->set('template', $template);
    /* 表示設定 */
    $this->pageTitle = '求人情報 編集';
    $this->render('form');
  }

  /**
  * [ADMIN] 削除
  *
  * @param int $id 求人情報ID
  * @return void
  */
  public function admin_delete($id = null) {
    /* 除外処理 */
    if (empty($id)) {
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }

    //情報の取得
    $category = $this->RecruitCategory->findById($id);

    if ($this->RecruitCategory->delete($id)) {
      $this->setMessage('求人情報のカテゴリ「'. h($category['RecruitCategory']['name']) .'」を削除しました。', false, true);
    } else {
      $this->setMessage('入力エラーです。削除に失敗しました。', true);
    }

    /* 表示設定 */
    $this->redirect(array('action' => 'index'));
  }

  /**
  * [ADMIN] 利用設定切替
  *
  * @return void
  */
  public function admin_publish($id){
    /* 除外処理 */
    if (empty($id)){
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }
    //現在の情報を取得する。
    $data = $this->RecruitCategory->find('first', array('conditions' => array(
      'RecruitCategory.id' => $id
    )));
    //非公開設定
    switch($data['RecruitCategory']['publish']){
      case 1:
      $data['RecruitCategory']['publish'] = 0;
      break;
      case 0:
      $data['RecruitCategory']['publish'] = 1;
      break;
    }

    //更新処理実行
    $this->RecruitCategory->id = $id;
    if ($this->RecruitCategory->save($data)) {
      $this->setMessage('求人情報のカテゴリ「'. h($data['RecruitCategory']['name']) . '」の利用設定を切替ました。', false, true);
      $this->redirect(array('action' => 'admin_index'));
    } else {
      $this->setMessage('入力エラーです。内容を修正してください。', true);
    }
  }
}
