<?php
/*
* 求人情報プラグイン
* 管理コントローラー
*
* PHP 5.4.x
*
* @copyright    Copyright (c) hiniarata co.ltd
* @link         https://hiniarata.jp
* @package      Recruit Plugin Project
* @since        ver.0.9.0
*/

/**
* 求人情報 管理コントローラー
*
* @package baser.plugins.recruit
*/
class RecruitConfigsController extends RecruitAppController {

  /**
  * クラス名
  *
  * @var string
  * @access public
  */
  public $name = 'RecruitConfigs';

  /**
  * コンポーネント
  *
  * @var array
  * @access public
  */
  public $components = array('BcAuth', 'Cookie', 'BcAuthConfigure', 'Security');

  /**
  * モデル
  *
  * @var array
  * @access public
  */
  public $uses = array(
    'Recruit.RecruitCategory',
    'Recruit.RecruitSetting',
    'Recruit.Recruit'
  );

  /**
  * ぱんくずナビ
  *
  * @var string
  * @access public
  */
  public $crumbs = array(
  array('name' => 'プラグイン管理', 'url' => array('plugin' => '', 'controller' => 'plugins', 'action' => 'index')),
  array('name' => '求人情報管理', 'url' => array('controller' => 'recruit_configs', 'action' => 'index'))
  );

  /**
  * サブ求人情報エレメント
  *
  * @var array
  * @access public
  */
  public $subMenuElements = array('recruit');

  /**
  * beforeFilter
  *
  * @return	void
  * @access 	public
  */
  public function beforeFilter() {
    parent::beforeFilter();
    //CSRF対策（トークンの有効期限延長）
    $this->Security->csrfCheck = true;
    $this->Security->csrfExpires = '+1 hour';
  }

  /**
  * [ADMIN] 一覧表示
  *
  * @return void
  */
  public function admin_index() {
  	// 画面表示情報設定
  	$default = array(
  		'named' => array(
  			'num' => $this->siteConfigs['admin_list_num']
  		),
  	);
  	$this->setViewConditions('Recruit', array('default' => $default));

    // 並び替えモードの場合は、強制的にsortフィールドで並び替える
    if (!empty($this->passedArgs['sortmode'])) {
      $this->passedArgs['sort'] = 'sort';
      $this->passedArgs['direction'] = 'asc';
      $this->set('sortmode', true);
      //設定
      $this->paginate = array(
          'fields' => array(),
          'order' => 'Recruit.sort',
          'limit' => $this->passedArgs['num']
      );
    } else {
      $this->set('sortmode', false);
      //設定
      $this->paginate = array(
          'fields' => array(),
          'order' => 'Recruit.id DESC',
          'limit' => $this->passedArgs['num']
      );
    }

    /* 表示設定 */
    $this->set('recruits', $this->paginate('Recruit'));
    $this->pageTitle = '求人情報一覧';
    $this->help = 'recruit_configs_index';
  }

  /**
  * [ADMIN] 新規登録
  *
  * @return void
  */
  public function admin_add() {
    //設定状況の確認
    $setting = $this->RecruitSetting->find('first');

    //登録ボタン押下後
    if (!empty($this->request->data)) {
      //画像の最大値を確認する
      if (!empty($setting['RecruitSetting']['max_width'])) {
        $maxWidth = $setting['RecruitSetting']['max_width'];
      } else {
        $maxWidth = null;
      }
      if (!empty($setting['RecruitSetting']['max_height'])) {
        $maxHeight = $setting['RecruitSetting']['max_height'];
      } else {
        $maxHeight = null;
      }

      //画像保存処理実行
      $insertData = $this->Recruit->savePostImg($this->request->data, $maxWidth, $maxHeight);

      //シリアライズ（スキル）
      if (!empty($this->request->data['Recruit']['tags'])) {
        $insertData['Recruit']['tags'] = serialize($this->request->data['Recruit']['tags']);
        //スキル検索ラベル化する（LIKE句で引っ張れるようにするため）
        $searchLabels = '';
        for($l=0; $l<count($this->request->data['Recruit']['tags']); $l++){
          $searchLabels .= 's'.$this->request->data['Recruit']['tags'][$l].',';
        }
        $insertData['Recruit']['tag_search_label'] = $searchLabels;
      }

      //現在の最大ソート番号を取得する。
      $maxSort = $this->Recruit->find('first', array(
                      //'fields' => 'MAX(Recruit.sort)'
                      'fields' => 'MAX(sort)'
                  ));
      //次回のソート番号
      //var_dump($maxSort);exit;
      //$nextCount = $maxSort[0]['MAX(`Recruit`.`sort`)'] +1;
      $nextCount = $maxSort[0]["MAX(sort)"] +1;
      $insertData['Recruit']['sort'] = $nextCount;

      //生成
      $this->Recruit->create();
      //保存
      if ($this->Recruit->save($insertData)) {
        $this->setMessage('求人情報「'. h($this->request->data['Recruit']['name']) .'」を登録しました。', false, true);
        $this->redirect(array('action' => 'index'));
      } else {
        $this->setMessage('入力エラーです。内容を修正してください。', true);
      }
    }
    //ckeditor
    $editorOptions = array('editorDisableDraft' => true);
    if (!empty($this->siteConfigs['editor_styles'])) {
      App::uses('CKEditorStyleParser', 'Vendor');
      $CKEditorStyleParser = new CKEditorStyleParser();
      $editorStyles = array('default' => $CKEditorStyleParser->parse($this->siteConfigs['editor_styles']));
      $editorOptions = array_merge($editorOptions, array(
        'editorStylesSet' => 'simple',
        'editorStyles' => $editorStyles
      ));
    }
    $this->set('editorOptions', $editorOptions);

    //カテゴリ情報取得
    $categories = $this->RecruitCategory->find('list', array('conditions' => array(
      'RecruitCategory.publish' => 1
    )));

    //現在の設定が入っていない可能せがあるので、デフォルト値を付けておく。
    if (empty($setting)) {
      $setting['RecruitSetting']['editor_type'] = 'ckeditor';
      $setting['RecruitSetting']['image01'] = 0;
      $setting['RecruitSetting']['image02'] = 0;
      $setting['RecruitSetting']['image03'] = 0;
      $setting['RecruitSetting']['image04'] = 0;
      $setting['RecruitSetting']['other01'] = 0;
      $setting['RecruitSetting']['other02'] = 0;
      $setting['RecruitSetting']['other03'] = 0;
      $setting['RecruitSetting']['other04'] = 0;
      $setting['RecruitSetting']['url01'] = 0;
    }

    /* 表示設定 */
    $this->pageTitle = '求人情報 新規登録';
    $this->set('setting', $setting);
    $this->set('categories', $categories);
    $this->help = 'recruit_configs_form';
    $this->render('form');
  }

  /**
  * [ADMIN] 編集
  *
  * @param int $id 求人情報ID
  * @return void
  */
  public function admin_edit($id = null) {
    /* 除外処理 */
    if (empty($id)) {
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }

    /* 既存データ取得 */
    $recruit = $this->Recruit->findById($id);

    /* 除外処理 */
    if (empty($recruit)) {
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }

    //設定状況の確認
    $setting = $this->RecruitSetting->find('first');

    //登録ボタン押下後
    if (!empty($this->request->data)) {
      //画像の最大値を確認する
      if (!empty($setting['RecruitSetting']['max_width'])) {
        $maxWidth = $setting['RecruitSetting']['max_width'];
      } else {
        $maxWidth = null;
      }
      if (!empty($setting['RecruitSetting']['max_height'])) {
        $maxHeight = $setting['RecruitSetting']['max_height'];
      } else {
        $maxHeight = null;
      }
      //画像保存処理実行
      $insertData = $this->Recruit->savePostImg($this->request->data, $maxWidth, $maxHeight);

      //保存
      if ($this->Recruit->save($insertData)) {
        $this->setMessage('求人情報「'. h($this->request->data['Recruit']['name']) .'」を編集しました。', false, true);
        $this->redirect(array('action' => 'index'));
      } else {
        $this->setMessage('入力エラーです。内容を修正してください。', true);
      }

      //編集画面初期表示
    } else {
      $this->request->data = $recruit;
    }

    //ckeditor
    $editorOptions = array('editorDisableDraft' => true);
    if (!empty($this->siteConfigs['editor_styles'])) {
      App::uses('CKEditorStyleParser', 'Vendor');
      $CKEditorStyleParser = new CKEditorStyleParser();
      $editorStyles = array('default' => $CKEditorStyleParser->parse($this->siteConfigs['editor_styles']));
      $editorOptions = array_merge($editorOptions, array(
        'editorStylesSet' => 'simple',
        'editorStyles' => $editorStyles
      ));
    }
    $this->set('editorOptions', $editorOptions);

    //画像があれば表示させるため、取得した情報と画像パスをセットする。
    $this->set('recruit', $recruit);
    $this->set('imgPath', '/img/recruit_plugin/');

    //カテゴリ情報取得
    $categories = $this->RecruitCategory->find('list', array('conditions' => array(
      'RecruitCategory.publish' => 1
    )));

    //現在の設定が入っていない可能せがあるので、デフォルト値を付けておく。
    if (empty($setting)) {
      $setting['RecruitSetting']['editor_type'] = 'ckeditor';
      $setting['RecruitSetting']['image01'] = 0;
      $setting['RecruitSetting']['image02'] = 0;
      $setting['RecruitSetting']['image03'] = 0;
      $setting['RecruitSetting']['image04'] = 0;
      $setting['RecruitSetting']['other01'] = 0;
      $setting['RecruitSetting']['other02'] = 0;
      $setting['RecruitSetting']['other03'] = 0;
      $setting['RecruitSetting']['other04'] = 0;
      $setting['RecruitSetting']['url01'] = 0;
    }

    /* 表示設定 */
    $this->pageTitle = '求人情報 編集';
    $this->set('categories', $categories);
    $this->set('setting', $setting);
    $this->help = 'recruit_configs_form';
    $this->render('form');
  }

  /**
  * [ADMIN] 削除
  *
  * @param int $id 求人情報ID
  * @return void
  */
  public function admin_delete($id = null) {
    /* 除外処理 */
    if (empty($id)) {
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }

    //情報の取得
    $recruit = $this->Recruit->findById($id);

    if ($this->Recruit->delete($id)) {
      //画像も削除する。
      for ($i = 1; $i <= 4; $i++) {
        if (!empty($recruit['Recruit']['image_'.$i])) {
          $this->Recruit->deleteSaveImage($recruit['Recruit']['image_'.$i]);
        }
      }
      $this->setMessage('求人情報「'. h($recruit['Recruit']['name']) .'」を削除しました。', false, true);
    } else {
      $this->setMessage('入力エラーです。削除に失敗しました。', true);
    }

    /* 表示設定 */
    $this->redirect(array('action' => 'index'));
  }

  /**
  * [ADMIN] 公開設定切替
  *
  * @return void
  */
  public function admin_publish($id){
    /* 除外処理 */
    if (empty($id)){
      $this->setMessage('無効なIDです。', true);
      $this->redirect(array('action' => 'index'));
    }
    //現在の情報を取得する。
    $data = $this->Recruit->find('first', array('conditions' => array(
      'Recruit.id' => $id
    )));
    //非公開設定
    switch($data['Recruit']['publish']){
      case 1:
      $data['Recruit']['publish'] = 0;
      break;
      case 0:
      $data['Recruit']['publish'] = 1;
      break;
    }

    //更新処理実行
    $this->Recruit->id = $id;
    if ($this->Recruit->save($data)) {
      $this->setMessage('求人情報「'. h($data['Recruit']['name']) . '」の公開設定を切替ました。', false, true);
      $this->redirect(array('action' => 'admin_index'));
    } else {
      $this->setMessage('入力エラーです。内容を修正してください。', true);
    }
  }


/**
* 並び替えを更新する [AJAX]
*
* @access public
* @return boolean
*/
public function admin_ajax_update_sort() {
  if ($this->request->data) {
    $this->setViewConditions('RecruitConfigs', array('action' => 'admin_index'));
    $conditions = array();
    if ($this->Recruit->changeSort($this->request->data['Sort']['id'], $this->request->data['Sort']['offset'], $conditions)) {
      clearViewCache();
      clearDataCache();
      echo true;
    } else {
      $this->ajaxError(500, '一度リロードしてから再実行してみてください。');
    }
  } else {
    $this->ajaxError(500, '無効な処理です。');
  }
  exit();
}
}
