<?php
/*
* 求人情報プラグイン
* フロント側 コントローラー
*
* PHP 5.4.x
*
* @copyright    Copyright (c) hiniarata co.ltd
* @link         https://hiniarata.jp
* @package      Recruit Plugin Project
* @since        ver.0.9.0
*/

/**
*  フロント側 コントローラー
*
* @package    baser.plugins.recruit
*/
class RecruitsController extends RecruitAppController {

  /**
  * クラス名
  *
  * @var string
  * @access public
  */
  public $name = 'Recruits';

  /**
  * コンポーネント
  *
  * @var array
  * @access public
  */
  public $components = array();

  /**
  * モデル
  *
  * @var array
  * @access public
  */
  public $uses = array('Recruit.Recruit', 'Recruit.RecruitCategory');

  /**
  * beforeFilter
  *
  * @return	void
  * @access 	public
  */
  public function beforeFilter() {
    parent::beforeFilter();
  }

  /**
  *  一覧表示
  *
  * @param int $categoryId カテゴリID
  * @return void
  */
  public function index($categoryId = null){
    //1ページの表示件数
    $limit = 10;
    //検索条件
    $conditions = array();
    $conditions[] = array('Recruit.publish' => 1); //公開中
    $conditions[] =
        array('OR' =>
          array(
            array('Recruit.recruit_category_id' => null),
            array('RecruitCategory.publish' => 1)
        ));

    //カテゴリ指定があった場合
    if (!empty($categoryId)) {
      $conditions[] = array('Recruit.recruit_category_id' => $categoryId);
      //コンテンツテンプレートの設定を読み込む
      $categoryData = $this->RecruitCategory->findById($categoryId);
      if (!empty($categoryData['RecruitCategory']['template'])) {
        $template = $categoryData['RecruitCategory']['template'] . DS . 'index';
      }
    }

    //ページネート
    $this->paginate = array('conditions' => $conditions,
      'order' => 'Recruit.sort ASC',
      'limit' => $limit
    );

    //ここまでの所でコンテンツテンプレートが設定なし
    //初期テンプレートを使用する
    if (empty($template)) {
      $template = 'default' . DS . 'index';
    }

    /* 表示設定 */
    $this->set('recruits', $this->paginate('Recruit'));
    $this->pageTitle = '求人情報一覧';
    $this->render($template);
  }

/**
 * [MOBILE] 一覧表示
 *
 * @return void
 * @access public
 */
  public function mobile_index($categoryId = null) {
    $this->setAction('index', $categoryId);
  }

/**
 * [SMARTPHONE] 一覧表示
 *
 * @return void
 * @access public
 */
  public function smartphone_index($categoryId = null) {
    $this->setAction('index', $categoryId);
  }

  /**
  *  個別表示
  *
  * @param int $recruitId 求人情報ID
  * @return void
  */
  public function view($recruitId = null){
    /* 除外処理 */
    if (empty($recruitId)) {
      $this->redirect(array('action' => 'index'));
    }
    //データの取得
    $recruitData = $this->Recruit->find('first', array('conditions' => array(
        'Recruit.id' => $recruitId,
        'Recruit.publish' => 1,
        'AND' => array('OR' =>
          array(
            array('RecruitCategory.publish' => 1),
            array('Recruit.recruit_category_id' => null),
          )
        )
    )));

    if (empty($recruitData)) {
      $this->redirect(array('action' => 'index'));
    }

    //カテゴリ指定があった場合はテンプレートを確認する
    if (!empty($recruitData['RecruitCategory']['template'])) {
      $template = $recruitData['RecruitCategory']['template'] . DS . 'view';
    }

    //カテゴリに入っていない、テンプレートの指定がないなどの場合
    if (empty($template)) {
      $template = 'default' . DS . 'view';
    }

    /* 表示設定 */
    $this->set('recruit', $recruitData);
    $this->pageTitle = $recruitData['Recruit']['name'];
    $this->render($template);
  }

/**
 * [MOBILE] 個別表示
 *
 * @return void
 * @access public
 */
  public function mobile_view($id = null) {
    $this->setAction('index', $id);
  }

/**
 * [SMARTPHONE] 個別表示
 *
 * @return void
 * @access public
 */
  public function smartphone_view($id = null) {
    $this->setAction('index', $id);
  }


}
