<?php
/*
* 求人情報プラグイン
* 登録情報モデル
*
* PHP 5.4.x
*
* @copyright    Copyright (c) hiniarata co.ltd
* @link         https://hiniarata.jp
* @package      Recruit Plugin Project
* @since        ver.0.9.0
*/

/**
* Include files
*/
App::uses('RecruitApp', 'Recruit.Model');
App::uses('Imageresizer', 'Vendor'); //標準搭載の画像処理クラス

/**
* 登録情報モデル
*
* @package baser.plugins.recruit
*/
class Recruit extends RecruitApp {
  /**
  * クラス名
  *
  * @var string
  * @access public
  */
  public $name = 'Recruit';

  /**
  * プラグイン名
  *
  * @var string
  * @access public
  */
  public $plugin = 'Recruit';

  /**
  * DB接続時の設定
  *
  * @var string
  * @access public
  */
  public $useDbConfig = 'plugin';

  /**
  * アソシエーション
  *
  * @var string
  * @access public
  */
  public $belongsTo = array(
    'RecruitCategory' => array(
      'className'    => 'Recruit.RecruitCategory',
      'foreignKey'   => 'recruit_category_id'
    )
  );


  /**
  * 画像保存パス
  *
  * @var string
  * @access public
  */
  public $imageDir = 'recruit_plugin';

  /**
  * 画像のデフォルト幅（px）
  *
  * @var string
  * @access public
  */
  public $widthSize = 500;

  /**
  * 画像のデフォルト高さ（px）
  *
  * @var string
  * @access public
  */
  public $heightSize = 500;

  /**
  * 画像の枚数
  *
  * @var string
  * @access public
  */
  public $imageCount = 4;

  /**
  * validate
  *
  * @var array
  */

  public $validate = array(
    'last_name' => array(
      'notEmpty' => array(
        'rule' => array('notEmpty'),
        'message' => '姓を入力してください。'
    )),
    'first_name' => array(
      'notEmpty' => array(
        'rule' => array('notEmpty'),
        'message' => '名前を入力してください。'
    )),
    'last_name_rubi' => array(
      'notEmpty' => array(
        'rule' => array('notEmpty'),
        'message' => '姓（ふりがな）を入力してください。'
    )),
    'first_name_rubi' => array(
      'notEmpty' => array(
        'rule' => array('notEmpty'),
        'message' => '名前（ふりがな）を入力してください。'
    )),
    'text' => array(
      'notEmpty' => array(
        'rule' => array('notEmpty'),
        'message' => '本文を入力してください。'
    ))
  );


  /**
  * 画像を保存する。
  *
  * @params array $data
  * @params init $width
  * @params init $height
  * @return bool
  * @access public
  */
  public function savePostImg($data, $width = null, $height = null){

    //現在のデータを取得する。（画像に変更がなかった場合の処理）
    if (!empty($data['Recruit']['id'])) {
      $recruitData = $this->find('first', array('conditions' => array(
        'Recruit.id' => $data['Recruit']['id']
      )));
    }

    //画像の幅指定
    if (!empty($width)) {
      $limitWidth = $width;
    } else {
      $limitWidth = $this->widthSize; //デフォルト
    }
    if (!empty($height)) {
      $limitHeight = $height;
    } else {
      $limitHeight = $this->heightSize; //デフォルト
    }

    //ファイル送信の確認と保存処理
    for ($i = 1; $i <= $this->imageCount; $i++) {
      if (empty($data['Recruit']['del_image_'.$i]) || $data['Recruit']['del_image_'.$i] == 0) { //削除指定がない場合にのみアップ作業
        if (!empty($data['Recruit']['image_'.$i]['tmp_name'])) {
          //現在のファイル名と、そこから拡張子を確認する。
          $img = $this->_copyTmpImage($data['Recruit']['image_'.$i], 'recruit_'.$i.'_' , $limitWidth, $limitHeight);
          $data['Recruit']['image_'.$i] = $img;

        //ファイル送信なしの場合
        } else {
          //旧画像名をそのままセットする。
          if (!empty($recruitData['Recruit']['image_'.$i])) {
            $data['Recruit']['image_'.$i] = $recruitData['Recruit']['image_'.$i];
          } else {
            $data['Recruit']['image_'.$i] = "";
          }
        }

      //既存のファイルの削除指示がある場合。
      } else {
        $this->_deletePostImage('image_'.$i, $data);
        $data['Recruit']['image_'.$i] = ''; //フィールドも空をセット
      }
    }
    return $data;
  }

  /**
  * 画像を削除する。
  *
  * @params string $imgKey
  * @params array $data
  * @return bool
  * @access public
  */
  public function deleteSaveImage($imageName){
    //削除処理
    if (!empty($imageName)) {
      $delFileName = WWW_ROOT . 'img' . DS . $this->imageDir . DS . $imageName;
      if (file_exists($delFileName)) {
        @unlink($delFileName);
        return true;
      }else{
        return false;
      }
    }
  }

  /**
  * 一時ファイルから公開フォルダ上へコピーして
  * 新しいファイル名を返す。
  *
  * @params array $data
  * @params string $prefix
  * @params int $width
  * @params int $height
  * @return string
  * @access protected
  */
  protected function _copyTmpImage($data, $prefix, $width, $height) {
    //コピー元
    $fileName = $data['name'];
    $ext = pathinfo($fileName, PATHINFO_EXTENSION);
    //新しいファイル名を生成
    $fileNamePrefix = $prefix;
    $fileNameNo = date("YmdHis");
    $newFileName =  $fileNamePrefix.$fileNameNo;
    $imgPath = WWW_ROOT . 'img' . DS . $this->imageDir . DS . $newFileName . '.' . $ext;
    //一時ファイルから動かす。
    //サムネイル生成
    $Imageresizer = new Imageresizer();
    $Imageresizer->resize($data['tmp_name'], $imgPath, $width, $height);
    //一時ファイルを消し去ってしまう。
    return $newFileName . '.' . $ext;
  }

  /**
  * 画像を削除する。
  *
  * @params string $imgKey
  * @params array $data
  * @return bool
  * @access protected
  */
  protected function _deletePostImage($imgKey, $data){
    //現在のデータを確認する。
    $recruitData = $this->find('first', array(
      'conditions' => array(
        'Recruit.id' => $data['Recruit']['id']
      ),
      'field' => array(
        "Recruit.$imgKey" //メモリ節約の為必要なフィールドのみ取得
      )));
      //削除処理
      if (!empty($recruitData['Recruit']["$imgKey"])) {
        $delFileName = WWW_ROOT . 'img' . DS . $this->imageDir . DS . $recruitData['Recruit']["$imgKey"];
        if (file_exists($delFileName)) {
          @unlink($delFileName);
          return true;
        }else{
          return false;
        }
      }
    }

    /**
    * 並び順を変更する
    * @param string	$id
    * @param int			$offset
    * @param array		$conditions
    * @return boolean
    */
  	public function changeSort($id, $offset, $conditions = array()) {

      //バリデーション解除
      unset($this->validate);

  		if ($conditions) {
  			$_conditions = $conditions;
  		} else {
  			$_conditions = array();
  		}

  		// 一時的にキャッシュをOFFする
  		$this->cacheQueries = false;

  		$current = $this->find('first', array(
  			'conditions' => array($this->alias . '.id' => $id),
  			'fields' => array($this->alias . '.id', $this->alias . '.sort')
  		));

  		// 変更相手のデータを取得
  		if ($offset > 0) { // DOWN
  			$order = array($this->alias . '.sort');
  			$limit = $offset;
  			$conditions[$this->alias . '.sort >'] = $current[$this->alias]['sort'];
  		} elseif ($offset < 0) { // UP
  			$order = array($this->alias . '.sort DESC');
  			$limit = $offset * -1;
  			$conditions[$this->alias . '.sort <'] = $current[$this->alias]['sort'];
  		} else {
  			return true;
  		}

  		$conditions = array_merge($conditions, $_conditions);
  		$target = $this->find('all', array(
  			'conditions' => $conditions,
  			'fields' => array($this->alias . '.id', $this->alias . '.sort'),
  			'order' => $order,
  			'limit' => $limit,
  			'recursive' => -1
  		));

  		if (!isset($target[count($target) - 1])) {
        //ここで落ちる
  			return false;
  		}

  		$currentSort = $current[$this->alias]['sort'];
  		$targetSort = $target[count($target) - 1][$this->alias]['sort'];

  		// current から target までのデータをsortで範囲指定して取得
  		$conditions = array();
  		if ($offset > 0) { // DOWN
  			$conditions[$this->alias . '.sort >='] = $currentSort;
  			$conditions[$this->alias . '.sort <='] = $targetSort;
  		} elseif ($offset < 0) { // UP
  			$conditions[$this->alias . '.sort <='] = $currentSort;
  			$conditions[$this->alias . '.sort >='] = $targetSort;
  		}

  		$conditions = array_merge($conditions, $_conditions);
  		$datas = $this->find('all', array(
  			'conditions' => $conditions,
  			'fields' => array($this->alias . '.id', $this->alias . '.sort'),
  			'order' => $order,
  			'recursive' => -1
  		));

  		// 全てのデータを更新
  		foreach ($datas as $data) {
  			if ($data[$this->alias]['sort'] == $currentSort) {
  				$data[$this->alias]['sort'] = $targetSort;
  			} else {
  				if ($offset > 0) {
  					$data[$this->alias]['sort'] --;
  				} elseif ($offset < 0) {
  					$data[$this->alias]['sort'] ++;
  				}
  			}
  			if (!$this->save($data, false)) {
  				return false;
  			}
  		}
  		return true;
  	}
}
