<?php
/*
* 求人情報プラグイン
* 表示ヘルパー
*
* PHP 5.4.x
*
* @copyright    Copyright (c) hiniarata co.ltd
* @link         https://hiniarata.jp
* @package      Recruit Plugin Project
* @since        ver.0.9.0
*/
/* Model */
App::uses('AppHelper', 'View/Helper');
App::import('Model', 'Recruit.RecruitTag');
App::import('Model', 'Recruit.RecruitCategory');

class RecruitHelper extends AppHelper {

  /**
  * ヘルパー
  *
  * @var array
  */
  public $helpers = array('Html', 'BcBaser');

  /**
  * 求人情報名を表示する
  *
  * @param $recruit データ
  * @param $link リンクの有無
  * @param $options リンクオプション
  * @return void
  */
  public function recruitName($recruit, $link = false, $options = array()){
    echo $this->getRecruitName($recruit, $link, $options);
  }

  /**
  * 求人情報名を取得する
  *
  * @param $recruit データ
  * @param $link リンクの有無
  * @param $options リンクオプション
  * @return void
  */
  public function getRecruitName($recruit, $link = false, $options = array()){
    if ($link) {
      $url = array(
        'plugin' => 'recruit',
        'controller' => 'recruits',
        'action' => 'view',
        $recruit['Recruit']['id']
      );
      echo $this->Html->link($recruit['Recruit']['name'], $url, $options);
    } else {
      return $recruit['Recruit']['name'];
    }
  }

  /**
  * 募集職種を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function occupations($recruit){
    echo $this->getOccupations($recruit);
  }

  /**
  * 募集職種を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getOccupations($recruit){
    if (!empty($recruit['Recruit']['occupations'])) {
      return nl2br($recruit['Recruit']['occupations']);
    } else {
      return '';
    }
  }

  /**
  * 業務内容を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function businessContent($recruit){
    echo $this->getBusinessContent($recruit);
  }

  /**
  * 業務内容を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getBusinessContent($recruit){
    if (!empty($recruit['Recruit']['business_content'])) {
      return nl2br($recruit['Recruit']['business_content']);
    } else {
      return '';
    }
  }


  /**
  * 雇用形態を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function employmentStatus($recruit){
    echo $this->getEmploymentStatus($recruit);
  }

  /**
  * 雇用形態を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getEmploymentStatus($recruit){
    if (!empty($recruit['Recruit']['employment_status'])) {
      return nl2br($recruit['Recruit']['employment_status']);
    } else {
      return '';
    }
  }

  /**
  * 勤務地を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function location($recruit){
    echo $this->getLocation($recruit);
  }

  /**
  * 勤務地を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getLocation($recruit){
    if (!empty($recruit['Recruit']['location'])) {
      return nl2br($recruit['Recruit']['location']);
    } else {
      return '';
    }
  }


  /**
  * 給料を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function salaries($recruit){
    echo $this->getSalaries($recruit);
  }

  /**
  * 給料を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getSalaries($recruit){
    if (!empty($recruit['Recruit']['salaries'])) {
      return nl2br($recruit['Recruit']['salaries']);
    } else {
      return '';
    }
  }

  /**
  * 昇給・賞与を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function raiseAndBonus($recruit){
    echo $this->getRaiseAndBonus($recruit);
  }

  /**
  * 昇給・賞与を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getRaiseAndBonus($recruit){
    if (!empty($recruit['Recruit']['raise_and_bonus'])) {
      return nl2br($recruit['Recruit']['raise_and_bonus']);
    } else {
      return '';
    }
  }

  /**
  * 待遇・福利厚生を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function treatmentAndWelfare($recruit){
    echo $this->getTreatmentAndWelfare($recruit);
  }

  /**
  * 待遇・福利厚生を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getTreatmentAndWelfare($recruit){
    if (!empty($recruit['Recruit']['treatment_and_welfare'])) {
      return nl2br($recruit['Recruit']['treatment_and_welfare']);
    } else {
      return '';
    }
  }

  /**
  * 学歴を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function educationalBackground($recruit){
    echo $this->getEducationalBackground($recruit);
  }

  /**
  * 学歴を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getEducationalBackground($recruit){
    if (!empty($recruit['Recruit']['educational_background'])) {
      return nl2br($recruit['Recruit']['educational_background']);
    } else {
      return '';
    }
  }

  /**
  * 経験を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function qualifications($recruit){
    echo $this->getQualifications($recruit);
  }

  /**
  * 経験を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getQualifications($recruit){
    if (!empty($recruit['Recruit']['qualifications'])) {
      return nl2br($recruit['Recruit']['qualifications']);
    } else {
      return '';
    }
  }

  /**
  * 就業時間を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function workingHours($recruit){
    echo $this->getWorkingHours($recruit);
  }

  /**
  * 就業時間を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getWorkingHours($recruit){
    if (!empty($recruit['Recruit']['working_hours'])) {
      return nl2br($recruit['Recruit']['working_hours']);
    } else {
      return '';
    }
  }

  /**
  * 休暇・休日を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function holiday($recruit){
    echo $this->getHoliday($recruit);
  }

  /**
  * 休暇・休日を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getHoliday($recruit){
    if (!empty($recruit['Recruit']['holiday'])) {
      return nl2br($recruit['Recruit']['holiday']);
    } else {
      return '';
    }
  }

  /**
  * 応募方法を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function apply($recruit){
    echo $this->getApply($recruit);
  }

  /**
  * 応募方法を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getApply($recruit){
    if (!empty($recruit['Recruit']['apply'])) {
      return nl2br($recruit['Recruit']['apply']);
    } else {
      return '';
    }
  }

  /**
  * 選考方法を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function selectionMethod($recruit){
    echo $this->getSelectionMethod($recruit);
  }

  /**
  * 選考方法を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getSelectionMethod($recruit){
    if (!empty($recruit['Recruit']['selection_method'])) {
      return nl2br($recruit['Recruit']['selection_method']);
    } else {
      return '';
    }
  }

  /**
  * 問合せ方法を表示する
  *
  * @param $recruit データ
  * @return void
  */
  public function contact($recruit){
    echo $this->getContact($recruit);
  }

  /**
  * 問合せ方法を取得する
  *
  * @param $recruit データ
  * @return void
  */
  public function getContact($recruit){
    if (!empty($recruit['Recruit']['contact'])) {
      return nl2br($recruit['Recruit']['contact']);
    } else {
      return '';
    }
  }

  /**
  * 紹介文の本文を出力する。
  *
  * @param $recruit データ
  * @return void
  */
  public function content($recruit){
    echo $this->getContent($recruit);
  }

  /**
  * 紹介文の本文を取得する。
  *
  * @param $recruit データ
  * @return text
  */
  public function getContent($recruit){
    return $recruit['Recruit']['text'];
  }

  /**
  * 求人情報のカテゴリ名を出力する
  *
  * @param $recruit データ
  * @return void
  */
  public function category($recruit){
    echo $this->getCategory($recruit);
  }

  /**
  * 求人情報のカテゴリ名を取得
  *
  * @param $recruit データ
  * @return text
  */
  public function getCategory($recruit){
    //求人情報カテゴリ情報
    $cateModel = new RecruitCategory();
    $cateData = $cateModel->findById($recruit['Recruit']['recruit_category_id']);
    //返す
    if (!empty($cateData['RecruitCategory']['name'])) {
      return $cateData['RecruitCategory']['name'];
    } else {
      return "未分類";
    }
  }

  /**
  * 画像を出力する
  *
  * @param array $recruit データ
  * @param int $number 1〜4の画像番号
  * @return void
  */
  public function image($recruit, $number){
    $imageName = $this->getImageName($recruit, $number);
    if (!empty($imageName)) {
      echo $this->Html->image("recruit_plugin/". $imageName);
    }
  }

  /**
  * 画像名を取得する
  *
  * @param array $recruit データ
  * @param int $number 1〜4の画像番号
  * @return void
  */
  public function getImageName($recruit, $number){
    switch ($number) {
      case 1:
        return $recruit['Recruit']['image_1'];
        break;
      case 2:
        return $recruit['Recruit']['image_2'];
        break;
      case 3:
        return $recruit['Recruit']['image_3'];
        break;
      case 4:
        return $recruit['Recruit']['image_4'];
        break;
      default:
        return "";
        break;
    }
  }


  /**
  * 汎用項目を返す
  *
  * @param array $recruit データ
  * @param int $number 1〜4の汎用項目
  * @return void
  */
  public function otherField($recruit, $number){
    echo $this->getOtherField($recruit, $number);
  }

  /**
  * 汎用項目を返す
  *
  * @param array $recruit データ
  * @param int $number 1〜8の汎用項目
  * @return void
  */
  public function getOtherField($recruit, $number){
    switch ($number) {
      case 1:
        return $recruit['Recruit']['other_1'];
        break;
      case 2:
        return $recruit['Recruit']['other_2'];
        break;
      case 3:
        return $recruit['Recruit']['other_3'];
        break;
      case 4:
        return $recruit['Recruit']['other_4'];
        break;
      default:
        return "";
        break;
    }
  }

  /**
  * URLを返す
  *
  * @param array $recruit データ
  * @return void
  */
  public function recruitUrl($recruit){
    echo $this->getRecruitUrl($recruit);
  }

  /**
  * URLを取得する
  *
  * @param array $recruit データ
  * @return void
  */
  public function getRecruitUrl($recruit){
    if(!empty($recruit['Recruit']['url_1'])){
      return $recruit['Recruit']['url_1'];
    } else {
      return '';
    }
  }

}
